@@ -2,37 +2,15 @@ from __future__ import annotations
 import typing
 from typing import List, Optional, Callable, Tuple
 
-from antlr4.InputStream import InputStream
-from antlr4.FileStream import FileStream
-from antlr4.StdinStream import StdinStream
 from antlr4.Token import CommonToken
 from antlr4.tree.Tree import TerminalNodeImpl
 from antlr4.tree.Tree import ParseTree
-from antlr4 import ParserRuleContext
 
 
-from thrift_parser import parse
+from thrift_parser import ThriftData
 from thrift_parser.ThriftParser import ThriftParser
 
 
-class ThriftData(object):
-
-    def __init__(self, input_stream: InputStream):
-        _, tokens, _, document = parse(input_stream)
-        self._tokens: List[CommonToken] = tokens.tokens
-        self.document: ThriftParser.DocumentContext = document
-
-    @classmethod
-    def from_file(cls, file: str) -> ThriftData:
-        input_stream = FileStream(file, encoding='utf8')
-        return cls(input_stream)
-
-    @classmethod
-    def from_stdin(cls) -> ThriftData:
-        input_stream = StdinStream(encoding='utf8')
-        return cls(input_stream)
-
-
 class ThriftFormatter(object):
     def __init__(self, data: ThriftData):
         self._data: ThriftData = data
@@ -156,7 +134,7 @@ class ThriftFormatter(object):
 
         token_index = node.symbol.tokenIndex
         comments = []
-        for token in self._data._tokens[self._last_token_index + 1:]:
+        for token in self._data.tokens[self._last_token_index + 1:]:
             if token.channel != 2:
                 continue
             if self._last_token_index < token.tokenIndex < token_index:
@@ -184,9 +162,9 @@ class ThriftFormatter(object):
         if self._last_token_index == -1:
             return
 
-        last_token = self._data._tokens[self._last_token_index]
+        last_token = self._data.tokens[self._last_token_index]
         comments = []
-        for token in self._data._tokens[self._last_token_index + 1:]:
+        for token in self._data.tokens[self._last_token_index + 1:]:
             if token.line != last_token.line:
                 break
             if token.channel != 2:
@@ -211,7 +189,7 @@ class ThriftFormatter(object):
         fn(node)
 
     @staticmethod
-    def _get_repeat_children(nodes: List[ParseTree], cls: typing.Type[ParserRuleContext]) \
+    def _get_repeat_children(nodes: List[ParseTree], cls: typing.Type[ParseTree]) \
             -> Tuple[List[ParseTree], List[ParseTree]]:
         children:  List[ParseTree] = []
         for i, child in enumerate(nodes):
@@ -229,7 +207,7 @@ class ThriftFormatter(object):
         return isinstance(node, TerminalNodeImpl) and node.symbol.text == text
 
     @staticmethod
-    def is_newline_node(node: ParseTree):
+    def _is_newline_node(node: ParseTree):
         return isinstance(node, (
             ThriftParser.Enum_ruleContext,
             ThriftParser.Struct_Context,
@@ -245,7 +223,7 @@ class ThriftFormatter(object):
                 node = node.children[0]
 
             if i > 0:
-                if node.__class__ != last_node.__class__ or self.is_newline_node(node):
+                if node.__class__ != last_node.__class__ or self._is_newline_node(node):
                     self._newline(2)
                 else:
                     self._newline()
@@ -286,11 +264,11 @@ class ThriftFormatter(object):
     def TerminalNodeImpl(self, node: TerminalNodeImpl):
         assert isinstance(node, TerminalNodeImpl)
 
-        # add tail comment before new line
+        # add tail comment before a new line
         if self._newline_c > 0:
             self._tail_comment()
 
-        # add line comments
+        # add abrove comments
         self._line_comments(node)
 
         if self._is_EOF(node):
@@ -301,12 +279,10 @@ class ThriftFormatter(object):
             self._push(self._indent_s)
             self._indent_s = ''
 
-        # add token
         self._push(node.symbol.text)
 
     def DocumentContext(self, node: ThriftParser.DocumentContext):
         self._block_nodes(node.children)
-        self._newline()
 
     Type_ruleContext = _gen_inline_Context(join='')
     Const_ruleContext = _gen_inline_Context(join='')
@@ -372,6 +348,5 @@ class ThriftFormatter(object):
         return fn(self, node)
 
     def SenumContext(self, node: ThriftParser.SenumContext):
-        # TODO: add more rule
-        # SenumContext = _gen_subfields_Context(None, 3, ThriftParser.FieldContext)
+        # deprecated
         pass
